@@ -7,17 +7,17 @@ import mzo
 
 name = partial(
     click.argument,
-    'name',
+    "name",
     nargs=-1,
-    metavar='<recipient-name>...',
-    callback=lambda ctx, param, value: ' '.join(value),
+    metavar="<recipient-name>...",
+    callback=lambda ctx, param, value: " ".join(value),
 )
 
 
 amount = partial(
     click.argument,
-    'amount',
+    "amount",
     nargs=1,
     type=mzo.types.FloatRange(min=0),
-    metavar='<amount>',
+    metavar="<amount>",
 )
